==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/HierarchicalRingSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RingSeriesBaseDescriptionMetadata } from "./RingSeriesBaseDescriptionMetadata";
import { HierarchicalRingSeriesDescription } from "./HierarchicalRingSeriesDescription";
/**
 * @hidden
 */
export let HierarchicalRingSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class HierarchicalRingSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (HierarchicalRingSeriesDescriptionMetadata.a == null) {
                HierarchicalRingSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HierarchicalRingSeriesDescriptionMetadata.c(HierarchicalRingSeriesDescriptionMetadata.a);
            }
            if (a.k(HierarchicalRingSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(HierarchicalRingSeriesDescriptionMetadata.a);
        }
        static c(a) {
            RingSeriesBaseDescriptionMetadata.c(a);
            a.item("ChildrenMemberPath", "String");
        }
        static d(a) {
            HierarchicalRingSeriesDescriptionMetadata.b(a);
            a.ad("HierarchicalRingSeries", () => new HierarchicalRingSeriesDescription());
            a.ac("HierarchicalRingSeries", HierarchicalRingSeriesDescriptionMetadata.a);
        }
    }
    HierarchicalRingSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(HierarchicalRingSeriesDescriptionMetadata, 'HierarchicalRingSeriesDescriptionMetadata');
    HierarchicalRingSeriesDescriptionMetadata.a = null;
    return HierarchicalRingSeriesDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/HierarchicalRingSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RingSeriesBaseDescriptionMetadata } from "./RingSeriesBaseDescriptionMetadata";
import { HierarchicalRingSeriesDescription } from "./HierarchicalRingSeriesDescription";
/**
 * @hidden
 */
export let HierarchicalRingSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class HierarchicalRingSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (HierarchicalRingSeriesDescriptionMetadata.a == null) {
                HierarchicalRingSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HierarchicalRingSeriesDescriptionMetadata.c(HierarchicalRingSeriesDescriptionMetadata.a);
            }
            if (a.k(HierarchicalRingSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(HierarchicalRingSeriesDescriptionMetadata.a);
        }
        static c(a) {
            RingSeriesBaseDescriptionMetadata.c(a);
            a.item("ChildrenMemberPath", "String");
        }
        static d(a) {
            HierarchicalRingSeriesDescriptionMetadata.b(a);
            a.ae("HierarchicalRingSeries", () => new HierarchicalRingSeriesDescription());
            a.ad("HierarchicalRingSeries", HierarchicalRingSeriesDescriptionMetadata.a);
        }
    }
    HierarchicalRingSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(HierarchicalRingSeriesDescriptionMetadata, 'HierarchicalRingSeriesDescriptionMetadata');
    HierarchicalRingSeriesDescriptionMetadata.a = null;
    return HierarchicalRingSeriesDescriptionMetadata;
})();
